/**********************************************************************\
*                                                                      *
*  Title:  Gopt                                                        *
*  Version: 2.0                                                        *
*  Date:  2003-07-14                                                   *
*  Author(s): Tom Vajzovic                                             *
*  Copyright:  Tom Vajzovic                                            *
*  URL:  http://www.ug-home.nottingham.ac.uk/~ppywtcv/gopt/            *
*  Contact:  ppywtcv@nottingham.ac.uk                                  *
*  Description: A GNU compliant command line argument parsing library  *
*                                                                      *
*  You may redistribute and modify this free software under the terms  *
*  of version 2 of the GNU General Public License as published by the  *
*  Free Software Foundation.  http://www.gnu.org/copyleft/gpl.txt      *
*                                                                      *
*  (NOT the Library/Lesser GPL, the full GPL)                          *
*                                                                      *
*  If you redistribute a modified version of this software you must    *
*  do so under a different name.                                       *
*                                                                      *
*  Additionally, the author requests (but does not require) to be      *
*  notified, and that a comment containing the above URL be included.  *
*                                                                      *
\**********************************************************************/

/* gopt() return values */
#define GOPT_NOTPRESENT      0
#define GOPT_PRESENT_NOARG   1
#define GOPT_PRESENT_WITHARG 2

/* returns a void pointer to an area of memory which must be free()d when you have finished reading options */
/* the void* must be passed as the first argumnent each time you call gopt.                                 */
/* returns NULL and does nothing if out of memory                                                           */
void *gopts(const char* const shortoptswithargs, int* const mainargc, char** const*const mainargv);

/* returns GOPT_NOTPRESENT if --option (string longname) or  -o (char shortname) were not specified at execution   */
/* returns GOPT_PRESENT_NOARG if the option was specified (in either format) without an argument                   */
/* returns GOPT_PRESENT_WITHARG and loads argval with a pointer to the argument if it was present with an argument */
/* use gopt(opts,0,"option",&ptr) if there is no short option or gopt(opts,'o',"",&ptr) for no long.               */
unsigned char gopt(void *opts, const char shortname, const char *longname, char **argval);

#ifdef GOPT_FREE
/* wrapper for free() in case of several malloc implementations */
void gopt_free(void *vptr);
#endif
